NLSL: errmsg.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

errmsg.f90
Go to the documentation of this file.
1 c NLSL Version 1.9.0 beta 2/3/15
2 c----------------------------------------------------------------------
3 c =========================
4 c module ERRMSG
5 c =========================
6 c
7 c Contains text for error messages and definitions of symbols used
8 c to define error message numbers. Errors after ZEROB0=16 are defined
9 c as fatal, and will cause the calculation to halt.
10 c
11 c This module replaces errmsg.inc and the second half of nlstxt.f.
12 c
13 c For eprerr, the definitions of the symbols are as follows:
14 c
15 c ZEROIN2 Zero nuclear spin assumed
16 c POSB0 Positive B0 assumed
17 c BADHIFLD High-field approx. may not apply
18 c BADJMP Nonzero potential with jump/free: ipdf set to 0
19 c BADAV Zero potential with aniso. viscos.: ipdf set to 0
20 c BADDJ Discrete jumps with aniso. viscos.: ipdf set 0
21 c LEMXHI lemx must be 48 or less with potenti
22 c BSSADJ Basis set adjusted to (iii,iii,iii,iii,iii,iii,ii)
23 c NSTEPHI NSTEP too large: adjusted to iiiii
24 c CGTOLHI CGTOL too small: adjusted to xxxxxxxxx
25 c SHIFTHI SHIFTR too small: adjusted to xxxxxxxxx
26 c NOCONVRG CG did not converge after iiiii steps
27 c NOALPHAM Angle alm not needed with axial g-matrix
28 c NOALPHAD Angle ald not needed with axial diffusion tensor
29 c ZEROB0 Zero B0
30 c ZEROG Zero g-tensor element
31 c TDGERR Error in tridiagonal matrix storage
32 c MTXBIG Too many matrix elements
33 c DIMBIG Matrix dimension too large
34 c MTXHLT User halt during matrix calculation
35 c CGHLT User halt during CG tridiagonalization
36 c TDGBIG Too many tridiagonal matrix elements
37 c NOMIN Bracketing routine (search command) did not find a minimum
38 c ZERONFLD NFIELD is zero (no points in spectrum)
39 c ZRORANGE RANGE is zero
40 c
41 c For minerr, the meanings of the INFO index values are found in the
42 c comments at the beginning of lmnls.f.
43 c
44 c----------------------------------------------------------------------
45
46 module errmsg
47 implicit none
48
49 integer, parameter :: fatal=16,neperr=26,nmnerr=12
50 c
51 integer, parameter :: zeroin2=1,posb0=2,
52 # badhifld=3,badjmp=4,badav=5,baddj=6,
53 # lemxhi=7,bssadj=8,nstephi=9,cgtolhi=10,shifthi=11,
54 # noconvrg=12,noalpham=13,noalphad=14,badbess=15,
55 # zerob0=16,zerog=17,tdgerr=18,mtxbig=19,
56 # dimbig=20,mtxhlt=21,cghlt=22,tdgbig=23,nomin=24,
57 # zeronfld=25,zrorange=26
58
59 character*50, dimension(NEPERR), save ::
60 # eprerr =
61 1 (/ 'Zero nuclear spin assumed ' ,
62 2 'Positive B0 assumed ' ,
63 3 'High-field approx. may not apply ' ,
64 4 'Nonzero potential with jump/free: ipdf set to 0 ' ,
65 5 'Zero potential with aniso. viscos.: ipdf set to 0 ' ,
66 6 'Discrete jumps with aniso. viscos.: ipdf set 0 ' ,
67 7 'lemx must be 48 or less with potential ' ,
68 8 'Basis set adjusted to (iii,iii,iii,iii,iii,iii,ii)' ,
69 9 'NSTEP too large: adjusted to iiiii ' ,
70 a 'CGTOL too small: adjusted to xxxxxxxxx ' ,
71 1 'SHIFTR too small: adjusted to xxxxxxxxx ' ,
72 2 'CG did not converge after iiiii steps ' ,
73 3 'Angle alpham not needed w/ axial g-matrix ' ,
74 4 'Angle alphad not needed w/ axial diffusion tensor ' ,
75 5 'Taylor series for Bessel function did not converge' ,
76 6 'Zero B0 ' ,
77 7 'Zero g-tensor element ' ,
78 8 'Error in tridiagonal matrix storage ' ,
79 9 'Too many matrix elements ' ,
80 a 'Matrix dimension too large ' ,
81 1 'User halt during matrix calculation ' ,
82 2 'User halt during CG tridiagonalization ' ,
83 3 'Too many tridiagonal matrix elements ' ,
84 4 'Bracketing did not find minimum within step bound ' ,
85 5 'Number of points in spectrum is zero ' ,
86 6 'Field range of spectrum is zero ' /)
87 c
88 character*32, dimension(0:NMNERR-1), save ::
89 # minerr = (/ 'Bad input parameters ' ,
90 1 'Chi-squared convergence ' ,
91 2 'X vector convergence ' ,
92 3 'Chi-squared/X vector convergence' ,
93 4 'Gradient convergence ' ,
94 5 'Max function evaluations reached' ,
95 6 'Max iterations reached ' ,
96 7 'FTOL too small ' ,
97 8 'XTOL too small ' ,
98 9 'Zero Jacobian or GTOL too small ' ,
99 a 'Terminated internally ' ,
100 1 'Single calculation completed ' /)
101
102 end module errmsg
errmsg::noalpham
integer, parameter noalpham
Definition: errmsg.f90:51
errmsg::badjmp
integer, parameter badjmp
Definition: errmsg.f90:51
errmsg::mtxbig
integer, parameter mtxbig
Definition: errmsg.f90:51
errmsg::nomin
integer, parameter nomin
Definition: errmsg.f90:51
errmsg::shifthi
integer, parameter shifthi
Definition: errmsg.f90:51
errmsg::bssadj
integer, parameter bssadj
Definition: errmsg.f90:51
errmsg::zerob0
integer, parameter zerob0
Definition: errmsg.f90:51
errmsg::badbess
integer, parameter badbess
Definition: errmsg.f90:51
errmsg::baddj
integer, parameter baddj
Definition: errmsg.f90:51
errmsg::tdgerr
integer, parameter tdgerr
Definition: errmsg.f90:51
errmsg::zerog
integer, parameter zerog
Definition: errmsg.f90:51
errmsg::nstephi
integer, parameter nstephi
Definition: errmsg.f90:51
errmsg::posb0
integer, parameter posb0
Definition: errmsg.f90:51
errmsg::nmnerr
integer, parameter nmnerr
Definition: errmsg.f90:49
errmsg::lemxhi
integer, parameter lemxhi
Definition: errmsg.f90:51
errmsg::badav
integer, parameter badav
Definition: errmsg.f90:51
errmsg::badhifld
integer, parameter badhifld
Definition: errmsg.f90:51
errmsg::zeroin2
integer, parameter zeroin2
Definition: errmsg.f90:51
errmsg::neperr
integer, parameter neperr
Definition: errmsg.f90:49
errmsg::cghlt
integer, parameter cghlt
Definition: errmsg.f90:51
errmsg::minerr
character *32, dimension(0:nmnerr-1), save minerr
Definition: errmsg.f90:88
errmsg::zeronfld
integer, parameter zeronfld
Definition: errmsg.f90:51
errmsg::zrorange
integer, parameter zrorange
Definition: errmsg.f90:51
errmsg::tdgbig
integer, parameter tdgbig
Definition: errmsg.f90:51
errmsg::noalphad
integer, parameter noalphad
Definition: errmsg.f90:51
errmsg::cgtolhi
integer, parameter cgtolhi
Definition: errmsg.f90:51
errmsg::noconvrg
integer, parameter noconvrg
Definition: errmsg.f90:51
errmsg::fatal
integer, parameter fatal
Definition: errmsg.f90:49
errmsg::mtxhlt
integer, parameter mtxhlt
Definition: errmsg.f90:51
errmsg::eprerr
character *50, dimension(neperr), save eprerr
Definition: errmsg.f90:59
errmsg::dimbig
integer, parameter dimbig
Definition: errmsg.f90:51
errmsg
Definition: errmsg.f90:46